@@ -26,15 +26,14 @@
 #include <QStyleFactory>
 #include <QImageReader>
 #include <string>
-#include <iostream>
 #include "mainwindowimpl.h"
 #include "dialogoptions.h"
 #include "dialoginfo.h"
 #include "formats.h"
 #include "inisettings.h"
 #include "sizeutil.h"
-#include "updatechecker.h"
 #include "dialogmultipageeditor.h"
+#include "dialogshowupdatemsg.h"
 #include "globals.h"
 
 using namespace Magick;
@@ -48,6 +47,7 @@ MainWindowImpl::MainWindowImpl(QWidget * parent)
     iAList = new QList<ImageAttributes>;
     convertThread = new Converter(this);
     dlgCStatus = new DialogConversionStatus(this);
+    updateChecker = new UpdateChecker();
 
     CachingSystem::init();
 
@@ -81,10 +81,7 @@ MainWindowImpl::MainWindowImpl(QWidget * parent)
     connect(labelPreview, SIGNAL(previewReady(int, int, double, double)), this, SLOT(showImageInformations(int, int, double, double)));
 
     connect(checkRelative, SIGNAL(stateChanged(int)), this, SLOT(setRelativeSizeCheckboxes(int)));
-    /*connect(radioOverwriteAsk, SIGNAL(clicked()), this, SLOT(setOverwriteStatus()));
-    connect(radioSkipExisting, SIGNAL(clicked()), this, SLOT(setOverwriteStatus()));
-    connect(radioOverwriteExisting, SIGNAL(clicked()), this, SLOT(setOverwriteStatus()));*/
-    //connect(radioOverwriteExisting, SIGNAL(stateChanged(int)), this, SLOT(setOverwriteStatus(int)));
+    connect(updateChecker, SIGNAL(updateAvailable(bool)), this, SLOT(updateAvailable(bool)));
 
     createActions();
     setupMenu();
@@ -101,14 +98,11 @@ MainWindowImpl::MainWindowImpl(QWidget * parent)
     treeWidget->setContextMenuPolicy(Qt::CustomContextMenu);
     createContextMenu();
 
-
     loadOptions();
 
     resetDisplays();
 
-    if (IniSettings::isAutoChechUpdates()) {
-        checkForUpdates();
-    }
+    checkForUpdates();
 
     checkVersion();
 }
@@ -172,7 +166,7 @@ void MainWindowImpl::createActions()
     connect(actionInfo, SIGNAL(triggered()), this, SLOT(about()));
     connect(actionDonatePaypal, SIGNAL(triggered()), this, SLOT(openPaypalLink()));
     connect(actionReportBug, SIGNAL(triggered()), this, SLOT(bugReport()));
-    connect(actionCheckForUpdates, SIGNAL(triggered()), this, SLOT(checkForUpdates()));
+    connect(actionCheckForUpdates, SIGNAL(triggered()), this, SLOT(manualCheckForUpdate()));
     connect(actionHelp, SIGNAL(triggered()), this, SLOT(onlineHelp()));
 
     // Create first toolbar button
@@ -1307,8 +1301,45 @@ void MainWindowImpl::openPaypalLink()
 
 void MainWindowImpl::checkForUpdates()
 {
-    UpdateChecker *up = new UpdateChecker();
-    up->checkForUpdates();
+    // Checks for updates at program startup
+    updateChecker->checkForUpdates();
+}
+
+void MainWindowImpl::manualCheckForUpdate()
+{
+    // Checks for updates when manually requested
+    bool update_available = updateChecker->isUpdateAvailable();
+
+    if (update_available) {
+        showUpdateDialog();
+    } else {
+        QString title = QString(tr("No updates available!"));
+        QString text = QString(tr("%1 is already updated to the most recent version."))
+                              .arg(globals::PROGRAM_NAME);
+
+        QMessageBox::information(this, title, text, QMessageBox::Ok, QMessageBox::Ok);
+    }
+}
+
+void MainWindowImpl::updateAvailable(const bool &isAvailable)
+{
+    // Signal received when updates are checked
+    if (isAvailable && IniSettings::isAutoChechUpdates()) {
+        showUpdateDialog();
+    }
+}
+
+void MainWindowImpl::showUpdateDialog()
+{
+    QString caption = QString(tr("New version is available!"));
+    QString message = QString(tr("A new version of %1 is available!\nWould you download it?"))
+                          .arg(globals::PROGRAM_NAME);
+
+    DialogShowUpdateMsg dlg(this, caption, message, IniSettings::isAutoChechUpdates());
+
+    if (dlg.exec()) {
+        QDesktopServices::openUrl(QUrl(DESTINATION_URL, QUrl::TolerantMode));
+    }
 }
 
 void MainWindowImpl::bugReport()
